<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

require 'vendor/autoload.php'; // Path to Composer autoload

use Kreait\Firebase\Factory;

// Path to your JSON key file
$serviceAccountPath = __DIR__ . '/serviceAccountKey.json'; // Update with the correct path

// Initialize Firebase using the Factory class with the JSON key file
$factory = (new Factory)->withServiceAccount($serviceAccountPath);

$storage = $factory->createStorage();

// Function to delete files from Firebase Storage that have exceeded 10 minutes since upload
function deleteExpiredFiles()
{
    global $storage;

    // Get the bucket
    $bucket = $storage->getBucket();

    // Example: Check files in 'cloudstore/' directory (adjust as per your bucket structure)
    $directory = 'cloudstore/';

    // List files in the directory
    $objects = $bucket->objects(['prefix' => $directory]);

    // Get the current time
    $currentTime = time();

    foreach ($objects as $object) {

        // Get the upload time from the object metadata
        $uploadTimestamp = strtotime($object->info()['timeCreated']);

        // Calculate time difference in minutes
         $minutesElapsed = ($currentTime - $uploadTimestamp) / 60;

        // Check if the file has been uploaded for more than 10 minutes
        if ($minutesElapsed > 1) {
            // Delete the file
            try {
                $object->delete();
                echo "File deleted successfully after expiration: " . $object->name() . "\n";
            } catch (\Exception $e) {
                echo "Error deleting file " . $object->name() . ": " . $e->getMessage() . "\n";
            }
        }
    }
}

// Example usage:
// Schedule deletion check (in a real scenario, this would be done by a cron job or scheduled task)
deleteExpiredFiles();
?>
