<?php
error_reporting(E_ALL);
ini_set('display_errors', 1);

require 'vendor/autoload.php'; // Path to Composer autoload

use Kreait\Firebase\Factory;

// Path to your JSON key file
$serviceAccountPath = __DIR__ . '/serviceAccountKey.json'; // Update with the correct path
$bucketdirectory = "cloudstore/";
// File to upload
$file = '1337970761990019745881250signedrajni10072000pdf.pdf'; // Replace with the path to your file
$prefixname = rand();
$deleteminute = "1";
// Initialize Firebase using the Factory class with the JSON key file
$factory = (new Factory)->withServiceAccount($serviceAccountPath);

$storage = $factory->createStorage();


// Ensure the file exists
if (!file_exists($file)) {
    die("File not found: $file");
}

// Storage bucket and destination in Firebase Storage
$bucket = $storage->getBucket();
$object = $bucket->upload(file_get_contents($file), [
    'name' => $bucketdirectory.$prefixname.basename($file)
]);

// Set the expiration date and time for the signed URL
$expirationDateTime = new \DateTime();
$expirationDateTime->modify('+'.$deleteminute.' minutes'); // Set the URL to expire in 10 minutes

// Get the download URL of the uploaded file with the expiration date
$downloadUrl = $object->signedUrl($expirationDateTime);

    echo '{
    "status":"200",
    "message":"File uploaded successfully",
    "url":"'.$downloadUrl.'"
    
}';
// Function to delete files from Firebase Storage that have exceeded 10 minutes since upload
function deleteExpiredFiles()
{
    global $storage;
    global $bucketdirectory;
    global $deleteminute;

    // Get the bucket
    $bucket = $storage->getBucket();
   // Example: Check files in 'cloudstore/' directory (adjust as per your bucket structure)
    $directory = $bucketdirectory;

    // List files in the directory
    $objects = $bucket->objects(['prefix' => $directory]);

    // Get the current time
    $currentTime = time();

    foreach ($objects as $object) {

        // Get the upload time from the object metadata
        $uploadTimestamp = strtotime($object->info()['timeCreated']);

        // Calculate time difference in minutes
         $minutesElapsed = ($currentTime - $uploadTimestamp) / 60;

        // Check if the file has been uploaded for more than 10 minutes
        if ($minutesElapsed > $deleteminute) {
            // Delete the file
            try {
                $object->delete();
                //echo "File deleted successfully after expiration: " . $object->name() . "\n";
            } catch (\Exception $e) {
                //echo "Error deleting file " . $object->name() . ": " . $e->getMessage() . "\n";
            }
        }
    }
}

// Example usage:
// Schedule deletion check (in a real scenario, this would be done by a cron job or scheduled task)
deleteExpiredFiles();
?>
